import 'package:contentsquare/src/modules/element_tree_scanner/element_locator_utils.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';

class _MockPrivateWidget extends StatelessWidget {
  const _MockPrivateWidget({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container();
  }
}

class MockPublicWidget extends StatelessWidget {
  const MockPublicWidget({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container();
  }
}

void main() {
  group('isElementPrivate', () {
    test(
        'should return true if the given Element originates from a private widget class',
        () {
      final Element element = StatelessElement(const _MockPrivateWidget());
      expect(isElementPrivate(element), true);
    });
    test(
        'should return true if the given Element originates from a private widget class',
        () {
      final Element element = StatelessElement(const MockPublicWidget());
      expect(isElementPrivate(element), false);
    });
  });

  group('trimGenericParams', () {
    test('should return the given ClassName if it has no generic params', () {
      expect(trimGenericParams('Container'), 'Container');
    });

    test('should return the geiven ClassName without the generic params', () {
      expect(trimGenericParams('NotificationListener<ScrollNotification>'),
          'NotificationListener');
      expect(
          trimGenericParams('BlocListener<BlocA, BlocAState>'), 'BlocListener');
      expect(
          trimGenericParams('MyWidget<MyNestedWidget<MyParam>>'), 'MyWidget');
    });
  });
}
